#
# spec file for package AusweisApp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           AusweisApp
Version:        2.0.3
Release:        1.2
Summary:        Official authentication app for German ID cards and residence permits
License:        EUPL-1.2
Group:          Productivity/Security
URL:            https://www.ausweisapp.bund.de
Source0:        https://github.com/Governikus/AusweisApp2/archive/%{version}.tar.gz
BuildRequires:  cmake
%if 0%{?suse_version} > 1500
BuildRequires:  gcc-c++
%else
BuildRequires:  gcc11-c++
%endif
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libopenssl-devel
BuildRequires:  ninja
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkgconfig
BuildRequires:  qt6-concurrent-devel
BuildRequires:  qt6-core-devel
BuildRequires:  qt6-core-private-devel
BuildRequires:  qt6-linguist-devel
BuildRequires:  qt6-network-devel
BuildRequires:  qt6-qml-devel
BuildRequires:  qt6-qmlworkerscript-devel
BuildRequires:  qt6-quick-devel
BuildRequires:  qt6-quickcontrols2-devel
BuildRequires:  qt6-shadertools-devel
BuildRequires:  qt6-statemachine-devel
BuildRequires:  qt6-svg-devel
BuildRequires:  qt6-websockets-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(libudev)
Provides:       AusweisApp2 = 2.0.0
Obsoletes:      AusweisApp2 < 2.0.0
Requires:       hicolor-icon-theme

%description
This app is developed and issued by the German government to be
used for online authentication with electronic German ID cards
and residence permits. To use this app, a supported RFID card
reader or compatible NFC smart phone is required.

%prep
%setup -q -n %{name}-%{version}

%build
%if 0%{?suse_version} <= 1500
export CC=gcc-11
export CXX=g++-11
%endif
export CFLAGS="%{optflags} -fPIC"
export CXXFLAGS="%{optflags} -fPIC"
%define __builder ninja
%cmake -DBUILD_SHARED_LIBS=OFF
ninja

%install
%cmake_install

%suse_update_desktop_file com.governikus.ausweisapp2 X-SuSE-DesktopUtility
install -DTm644 %{_builddir}/%{name}-%{version}/resources/images/npa.png %{buildroot}/%{_datadir}/icons/hicolor/96x96/apps/AusweisApp.png

%fdupes -s %{buildroot}/%{_prefix}

%files
%doc README.rst
%license LICENSE.txt LICENSE.officially.txt
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/metainfo
%{_datadir}/applications/com.governikus.ausweisapp2.desktop
%{_datadir}/icons/hicolor
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Fri Jan 19 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.3
  - Fixed crash on macOS 11.
  - Fixed missing German translation.
  - Fixed display of release notes.
* Sat Jan 13 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.2
  - Avoid showing hints to the PIN reset service.
- Pass original source tree name to %%setup macro
- Use original source tree name in %%install section
* Wed Nov 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.1
  - Fixed an issue where settings were not saved on iOS and macOS.
  - Fixed entitlements on macOS.
* Tue Nov  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.0
  - Renamed AusweisApp2 to AusweisApp.
  - Completely revised graphical user interface.
  - Dark mode is now supported on all platforms.
  - The display in landscape mode has been
    optimized and is now set automatically.
  - System font and size are now honored by the app.
  - Optimized usability of the title bar.
  - Online help is no longer available.
  - The provider list is no longer integrated in AusweisApp
    but can now be accessed via the AusweisApp website.
  - History of authentication processes has been removed.
  - The PDF export function for personal data has been removed.
  - macOS Catalina 10.15 is no longer supported.
  - Android 7 is no longer supported.
  - iOS 13 is no longer supported.
  - Updated Qt to version 6.5.3.
  - Updated OpenSSL to version 3.1.4.
- Pass adjusted source tree name to %%setup macro
- Use adjusted source tree name in %%install section
- Rename package from AusweisApp2 to AusweisApp
- Drop patches for issues fixed upstream
  + 0001-fix-ftbfs-with-qt6.6.patch
  + 0002-update-qml-for-qt6.6.patch
* Tue Oct 17 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to fix FTBFS with Qt 6.6
  + 0001-fix-ftbfs-with-qt6.6.patch
- Add patch to update QML for Qt 6.6
  + 0002-update-qml-for-qt6.6.patch
* Tue Aug  1 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.7
  - Fixed possible crash during start-up on Android
  + from version 1.26.6
  - Fixed possible crash during start-up on Android
* Wed Jul 26 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.5
  - Reworked the pairing process when using a smartphone as card reader.
    Both devices involved in pairing must be updated to version 1.26.5.
    Pairing AusweisApp 1.26.5 with older versions is not supported.
  - Progress is now also shown on the smartphone when using it as a card reader.
  - Enabled keyboard mode by default when using smartphone as a card reader.
  - When using keyboard mode on a smartphone as a card reader, showing the
    permissions can now be re-enabled in settings at any time.
  - Added a monochrome icon on Android.
  - Added handling for <Command> + <W> on macOS.
  - Removed the update function on macOS in favor of the Mac App Store.
  - Minor bug fixes and optimizations.
  - Fixed documentation for installation in corporate networks
    on macOS when configuring the setup wizard.
  - Optimized the size of the Android SDK.
  - Updated OpenSSL to version 3.0.9.
- Add qt6-core-private-devel to BuildRequires
* Sat Apr 29 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.4
  - Improved window management on macOS.
  - Minor bug fixes and optimizations.
  - Changed INTERRUPT to not always display an error icon.
  - Enabled "Access-Control-Allow-Private-Network"
    header to be set during status requests.
  - Changed CHANGE_PIN to return a FailureCode.
  - Fixed a crash with AirPlay in the iOS SDK.
  - Fixed private icons in the iOS SDK.
  - Added simulator support for explicit private keys as parameters.
  - Fixed cancel button in the iOS scan dialog of
    the SDK not cancelling the workflow.
* Thu Mar  9 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.3
  - Improvement of help and tutorial texts.
  - Improvements in diagnostics.
  - Fix an error in the NFC dialog on iOS.
  - Improved accessibility when entering PIN, CAN and PUK.
  - Introduction of unique FailureCodes in SDK.
  - Added the environment variable AUSWEISAPP2_AUTOMATIC_DEVELOPERMODE
    in the fully automated SDK.
  - Fixed incorrect progress display in SDK for iOS.
  - Added SECURESCREENKEYBOARD for corporate environments.
  - Bumped TargetSDK to 33 in SDK for Android.
  - Update of OpenSSL to version 3.0.8.
* Sun Feb  5 2023 Marcus Meissner <meissner@suse.com>
- switch to generic openssl-devel to allow openssl-3
* Mon Jan 23 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.2
  - Fixed notification when another application is running on the port in use.
  - Fixed crashes on Android.
  - Optimization of forwarding to "CommunicationErrorAddress" on iOS.
  - Improved installation of the proxy service for terminal server environments.
  - Fixed the setting for the setup wizard when installing in corporate networks.
* Sun Dec 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.26.1
  - Fixed the loss of settings on Android.
  - Fixed the use of non-public or deprecated APIs
    on macOS to comply with App Store Guidelines.
  + from version 1.26.0
  - Support for macOS 13.
  - Support for Windows Server 2016 (version 1607).
  - Support for Windows Server 2019.
  - Support for Windows Server 2022.
  - A proxy service is now available for multi-user operation in terminal
    server environments. Details can be found in the document "Guide To
    Installation In Corporate Networks".
  - Fixed crashes on Android.
  - The iOS SDK now supports the arm64 simulator.
  - Updated OpenSSL to version 3.0.7.
  - Updated Qt to version 6.4.1.
* Wed Nov  9 2022 ecsos <ecsos@opensuse.org>
- Add BuildRequires, so it can also build for Leap >= 15.4.
* Wed Nov  2 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.24.4
  * Fixed potential crashes due to OpenSSL (denial of service).
  * Updated OpenSSL to version 3.0.7.
* Sat Oct 29 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.24.3
  * Fixed crashes on Android.
  * Disabled (cloud) backup on Android and iOS.
  * Fixed the A11y display of the SaK pairing code on Android and iOS.
  * Blocked installation on unsupported versions of Windows 10.
  * Fixed compatibility with Qt 6.4.
  * Enabled the simulator in the Android and iOS SDK.
- Upgrade Qt build and runtime dependencies for Qt6
  + Add Qt6 packages to BuildRequires
  * qt6-concurrent-devel
  * qt6-core-devel
  * qt6-linguist-devel
  * qt6-network-devel
  * qt6-qml-devel
  * qt6-qmlworkerscript-devel
  * qt6-quick-devel
  * qt6-quickcontrols2-devel
  * qt6-shadertools-devel
  * qt6-statemachine-devel
  * qt6-svg-devel
  * qt6-websockets-devel
  + Drop all Qt5 packages from BuildRequires and Requires
- Run spec-cleaner
* Wed Sep  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.24.2
  * Fixed crashes on Android.
  * Fixed a bug with changing the transport PIN on desktop systems.
* Mon Sep  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.24.1
  * Support for the Russian and Ukrainian languages has been added.
  * Fixed some issues with regards to PersoSim.
* Thu Aug 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.24.0
  * Technical overhaul of the "Smartphone as card reader" function.
    The use of an ID card app2 older than 1.22.1 is no longer possible
    in combination with 1.24.0.
  * Various optimizations with regards to accessibility.
  * Support for "IPv6 only" home networks.
  * AusweisApp2 is now provided as a 64-bit application on Windows.
  * Official support for Windows 11.
  * Support for Windows 7 and Windows 8.1 has been discontinued.
  * Support for macOS 10.13 and 10.14 has been discontinued.
  * Support for Android 5 and 6 and has been discontinued.
  * Added an integrated ID card simulator for testing.
  * An automatic mode for authentication for tests is now possible.
  * AusweisApp2 is now available as a container SDK or Docker image. This
    can be controlled using WebSocket or the new automatic authentication.
  * Command line parameters can now be passed in the iOS SDK.
  * Support for SHA224 and SECP224 has been discontinued.
  * The partially-embedded SDK on Android has been discontinued.
  * The SDK now uses API level v2.
  * Updated OpenSSL to version 3.0.5.
  * Updated Qt to version 6.3.1.
* Sat May 28 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.7
  * Fixed a crash with the new system notifications on macOS 10.14+.
* Sat May 21 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.6
  * Problems with card communication when using the "Smartphone as
    card reader" function in Comfort mode have been fixed.
  * Starting with macOS 10.14, system notifications are now being used.
  * On macOS, the tray icon is now disabled by default.
    This can be re-enabled in the preferences.
  * On iOS, a new NFC scan was not possible under certain
    circumstances. This has been fixed.
  * When canceling an authentication, the app sometimes crashed
    on iOS. This has been fixed.
  * Minor bug fixes and optimizations.
  * Updated OpenSSL to version 1.1.1o.
* Fri Apr 15 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.5
  * Update of the release notes has been corrected.
  * On Windows 10, the window size is no longer
    changed after a language change.
  * Minor bug fixes and optimizations.
  * Under certain circumstances it was possible that
    the SDK did not send an INSERT_CARD message.
  * Update of OpenSSL to version 1.1.1n.
* Fri Feb 18 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.4
  * Fixed a random startup crash on Windows.
  * The reminder to change the transport PIN is no longer
    displayed for the PIN reset service or on-site readout.
  * Fixed the "Report a bug" feature on Android 12.
  * Fixed an issue where the iOS NFC dialog was displayed
    longer than necessary.
  * Under certain conditions it was possible that a workflow
    could not be started because a previous workflow had not
    been completed.
  * Minor bug fixes and optimizations.
  * If AusweisApp2 was started just as an SDK on Windows, the
    path of the AutoStart entry in the registry was rewritten
    nevertheless. This has been fixed.
  * The libraries can now be built with MSVC 2022.
* Thu Jan 20 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.3
  * Added references to the PIN reset letter in suitable places.
  * The expiration date is now shown in the self-identification dialog.
  * Fixed Youtube links.
  * Removed unneccessary Qt clipboard access on Android.
  * Fixed some dialogs being shown in the language of the operating system
    instead of the language set in the app's preferences on macOS.
  * Fixed crashes and incorrect behavior on Android 11.
  * More information is displayed on a queried password when using
    one of the Reiner SCT "komfort" series of card readers.
  * Add support for macOS 12.
  * Small fixes and improved accessibility.
  * Added the "developerMode" parameter to the RUN_AUTH variable.
  * Fixed a crash when using the --no-logfile and --keep options.
  * The ShowUI parameter is now displayed on mobile devices.
  * Update of OpenSSL to version 1.1.1m.
* Wed Mar 31 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.2
  * CyberJack RFID basis reader is working again on Windows.
  * Automatic start of the setup wizard when running AusweisApp2
    for the first time on desktop systems is working again now.
  * Fixed a bug in the self-idenfication dialog.
  * Fixed some crashes.
  * The Android SDK is now also made available on Maven Central
    as JCenter has been discontinued.
  * Support for authorization certificates with PIN management.
  * Update of OpenSSL to version 1.1.1k.
* Tue Mar 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.1
  * The release notes are now displayed within the app.
  * Improvements have been made to the display and reporting
    of error messages within the mobile app.
  * Fixed possible freezing of the app when checking the ID.
  * The pairing of a smartphone can now be started directly.
  * The mobile app now starts with the SaK view if this was
    the last setting used.
  * The smartphone function as a card reader can now always be
    activated on iOS.
  * Animations on iOS have been improved.
  * Minor bug fixes.
  * In the SDK for iOS, the handleInterrupt parameter was added to
    RUN_AUTH and RUN_CHANGE_PIN. Like the associated INTERRUPT command.
  * In the SDK for iOS, parameters have been added for RUN_AUTH and
    RUN_CHANGE_PIN, which allow messages to be displayed in the system
    scan dialog.
  * The following error is now returned in the SDK for an expired ID
    card: DocumentValidityVerificationFailed
  * Added support for the new protocol version for smartphones as card
    readers in accordance with the supplement to BSI TR-03112 Part 6.
  * A crash on Windows when pairing PersoSim has been fixed.
  * Added support for PersoSim for Android with host card emulation.
  * A possible infinite loop in the SDK for Android has been fixed.
  * Update of OpenSSL to version 1.1.1j.
- Drop patches for issues fixed upstream
  + 0001-fix-manpage-path.patch
* Wed Dec  2 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.22.0
  * PIN management has been revised.
  * App navigation on iOS and Android harmonized. The sidebar on Android has
    been removed and replaced with a bar at the bottom of the screen.
  * The "Help" area has been revised and restructured on all platforms.
    The software licenses can now be viewed within the application.
  * A new start page has been added on Android and iOS.
  * A function test can now be carried out on Android and iOS via the
    entry "Check device and ID card" on the start page.
  * Auxiliary animations have been added to Android and iOS to
    clarify possible positions for placing the ID card.
  * The one-off notice that the transport PIN must be changed
    has been added to Android and iOS.
  * Option entry and query for the permission "local network access" has been
    added on iOS 14. This is necessary for using a smartphone as a card reader.
  * AusweisAppp2 can now be installed on macOS via the App Store. Updates that
    appear in the future can be obtained automatically through the store.
  * The update mechanism on Windows has been revised. The download of the update
    and the start of the installation are now carried out automatically when an
    update is started.
  * Support for the German eID card for Union citizens has been added.
  * Support for macOS Sierra 10.12 has been discontinued.
  * Support for Bluetooth card readers has been discontinued.
  * Minor bug fixes.
  * The SDK now supports changing the PIN.
  * The SDK now supports displaying the permissions "PinManagement" and "CanAllowed".
  * Update of OpenSSL to version 1.1.1h.
  * Update of Qt to version 5.15.2.
- Add libQt5QuickTemplates2-devel to BuildRequires
- Add manpage to %%files section
- Add patch to fix manpage installation path
  + 0001-fix-manpage-path.patch
* Thu Sep  3 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.20.2
  * It is now possible to paste a PIN/CAN/PUK using the common methods of
    the operating system in use, enabling the use of password managers.
  * Fixed an issue on Android 9 and older which prevented switching the
    screen to the WiFi settings on some devices.
  * Some help texts have been improved.
  * A tooltip has been added to the Windows installer for the firewall settings.
  * Search performance in the provider screen has been improved.
  * Fixed an issue on Android where an error message was shown incorrectly when
    the ID card was presented to the card reader before starting authentication.
  * Display fonts have been improved on OnePlus devices.
  * On macOS, the app will now use the integrated graphics adapter if possible.
  * Small bug fixes.
  * Support for Android NDK 21.3 and SDK cmdline-tools 2.1 has been added.
  * Fixed a compatibility issue with Qt 5.10.
  * Fixed an issue where an incorrect text was shown in comfort mode when using
    a smartphone with the CAN-allowed function.
  * Fixed an issue on Android where the feedback screen was incorrectly shown
    after using the external SDK.
  * Documentation for the integrated SDK on Android has been extended to include
    logging facilities and App Bundles.
  * Use of more inclusive terminology, the terms "blacklist" and "suppressions"
    have been removed or renamed.
* Wed Jun 24 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.20.1
  * Password-protected proxy servers can now also be used from
    the new user interface.
  * A new option for mobile devices now allows switching between
    portrait and landscape viewing mode.
  * On Android, canceling the authentication process should now
    be faster and the previously occurring crash was fixed.
  * On Windows, a progress bar is now also shown during the
    authentication process when using the new user interface.
  * Small bug fixes.
  * Enterprise installations using the MSI package have gained the possibility
    to enable on-site-readout and providing a proxy configuration.
  * The mobile app now allows enabling and disabling debug mode when retrieving
    one's own personal ID data by tapping the magnifier icon ten times.
  * Also in the mobile app, tapping the version number in the about dialog
    ten times will now activate the advanced settings dialog which allows
    one to enable the on-site-readout.
- Drop patches for issues fixed upstream
  + 0001-disable-vendor-name.patch
  + 0002-fix-desktop-icon-path.patch
* Sat Jan 18 2020 Ismail Dönmez <idonmez@suse.com>
- Add Requires on libqt5-qtgraphicaleffects and libqt5-qtquickcontrols2
  This is required for the new default QML interface to work.
* Wed Jan 15 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.20.0
  * Introduce new graphical user interface for Windows and macOS
  * The DMG image for macOS is now signed
  * Support for screen readers on Android and iOS
  * Adjust color contrast for better readability
  * Optimize menu layout and introduce settings
    panel on iOS and Android
  * Optimize the functionality to use the smartphone as card reader
  * Support for macOS 10.11 was dropped
  * Support for x86 architecture on Android was dropped
  * Small bug fixes
  * Update OpenSSL to version 1.1.1d
  * Update Qt to version 5.12.5
- Add libqt5-qtdeclarative-devel and libQt5QuickControls2-devel
  to BuildRequires, required for QML-based user interface
- Add patch to disable vendor name
  + 0001-disable-vendor-name.patch
- Add patch to fix path to desktop icon
  + 0002-fix-desktop-icon-path.patch
- Drop custom icon
  + AusweisApp2.png
- Drop patches for issues fixed upstream
  + 0001-fix-resource-file-path.patch
  + 0002-fix-translation-files-path.patch
  + 0003-disable-auto-updater.patch
  + 0004-set-config-path.patch
  + 0005-disable-qtquick.patch
- Improve grammar and semantics in Summary and %%description
- Install npa_icon.png as desktop icon
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel:
  Allow OBS to shortcut through the -mini flavors.
* Mon Oct 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix capitalization of URL field descriptor
- Remove unnecessary %%defattr(-,root,root) from %%files section
- Remove unnecessary %%post and %%postun targets
  + Drop %%desktop_database_post and %%icon_theme_cache_post invocations
  + Drop %%desktop_database_postun and %%icon_theme_cache_postun invocations
- Sort dependencies in BuildRequires
- Switch cmake builder to Ninja
  + Add ninja to BuildRequires
  + Define __builder as ninja in %%build target
* Sun Oct 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Use correct SPDX identifier in License field for EUPL-1.2
* Sun Oct 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Fix incorrect package name in spec file header
- Update copyright year to 2019
- Use https connection in Bugzilla link
* Sun Oct 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove extra LICENSE.txt from packaging source
* Sat Oct 19 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.18.2
  * Small bug fixes
  * Updates to Info.plist file
  + Version 1.18.1
  * Updates to Info.plist file
  + Version 1.18.0
  * Enable NFC functionality for iOS 13
  * Small bug fixes
  * Updated OpenSSL version to 1.1.1c
  * Updated Qt version to 5.12.4
  * A compiler with C++17 support is now required
- Fix patch to set path to translation files
  + 0002-fix-translation-files-path.patch
- Refresh patches for new version
  + 0003-disable-auto-updater.patch
- Add patch to adjust path for config.json
  + 0004-set-config-path.patch
- Add patch to disable QtQuick as it's currently broken
  + 0005-disable-qtquick.patch
- Disable building shared libraries
  + Pass -DBUILD_SHARED_LIBS=off to cmake
  + Remove any references for *.so files from %%install and %%files sections
  + Remove generation of ld.conf.so configuration file
  + Remove invocations to /sbin/ldconfig from %%postin and %%postun sections
- Install config.json into data directory
- Remove libQt5QuickControls2-devel from BuildRequires
* Wed Jun  5 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.16.2
  * The cancel dialog is no longer shown when switching into PIN
    changing mode while in identification mode
  * On Android, old log files are now purged automatically
  * Smartphones that have been paired as card readers (SaK) are now shown as
    available if the connection has been established automatically by the app
  * Explanatory texts in the mobile app have been improved
  * The mobile app no longer performs a browser redirect when turning the transport
    PIN into a 6-digit custom PIN when in identfication mode
  * The error dialog has gained the possibility to send an email to the AusweisApp2
    support team; it will ask the user now to include the application log and the
    email automatically includes information about the system configuration as well
    as the most recent critical error messages
  * The integrated databases for supported cardreaders as well as online
    services supporting the electronic personal ID card have been updated
  * The version number of AusweisApp2 is no longer part of the installation
    path on Windows to avoid issues with anti-virus software
  * A bug that caused AusweisApp2 to crash in identification mode while
    running in the background has been fixed
  * Automatic detection of smartphones as card readers has been improved
  * Automatic detection of card readers in diagnosis mode has been improved
  * Other small bugs have been fixed
  * The default logger can now be disabled with "–no-loghandler"
  * Instructions for "Installing in company networks" have been extended
* Wed Jan  9 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 1.16.1
  * Deactivated automatic clean-up of old log files as
    that could cause a crash in version 1.16.0
  + Version 1.16.0
  * Small bug fixes
  * Added a tutorial to aid usage on Android devices
  * Dropped support for Android 4.3 and 4.4
  * Dropped support for OS X 10.10
  * Added support for macOS 10.14
  * It's now possible to transmit data from an Android smartphone
    anomynously after successful authentication
  * Extended the diagnostics functionality
  * Added popup question to rate app on Android
  * Added possibility to view logs on Android
  * On Android, the app now clearly differentiates
    between 5- and 6-digit PIN codes
  * Removing the ID card while entering PIN/CAN/PUK will no longer
    terminate the authentication or PIN changing process
  * Added support for corporate-wide deployments of the MSI
    package on Windows (separate documenation)
  * Added support for a WebSocket SDK on Windows and macOS
    (separate documentation)
  * Concurrent access from different applications to card readers
    which are connected through PC/SC is now possible
  * Updated OpenSSL version to 1.1.1
  * Updated Qt version to 5.11.2
  * Dropped support for TLS v1.1
  * Dropped support for the following TLS ciphers:
  - DHE-DSS-AES256-GCM-SHA384
  - DHE-DSS-AES256-SHA256
  - DHE-DSS-AES128-GCM-SHA256
  - DHE-DSS-AES128-SHA256
  - DHE-DSS-AES256-SHA
  - DHE-DSS-AES128-SHA
  - ECDHE-ECDSA-AES256-SHA
  - ECDHE-RSA-AES256-SHA
  - DHE-RSA-AES256-SHA
  - ECDHE-ECDSA-AES128-SHA
  - ECDHE-RSA-AES128-SHA
  - DHE-RSA-AES128-SHA
- Drop patches merged upstream
  + 0001-fix-desktop-menu-category.patch
  + 0002-add-desktop-menu-generic-name.patch
- Refresh and renumber patches for new version
  + 0001-fix-resource-file-path.patch
  + 0002-fix-translation-files-path.patch
  + 0003-disable-auto-updater.patch
* Thu Dec 27 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add patch to disable auto updater
  + 0005-disable-auto-updater.patch
- Rewrite Summary and %%description in English
* Sat Oct 27 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  + Version 1.14.3
